<?xml version="1.0"?>
<!--
    Turns certication XML into an indexed HTML document.
    Copyright (C)1999, 2000, 2002 Dylan Walsh.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-->
<!DOCTYPE xsl:stylesheet [<!ENTITY nbsp "&#160;">]> 
<xsl:stylesheet version="1.0" 	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" > 
 <xsl:output method="html" indent="yes" />
 <xsl:strip-space elements="*"/>

 <!-- 	
 Root element 
	Create HTML structure, insert title, author, disclaimer
	an index and then all the sections 
 -->
 <xsl:template match="document">
  <html>
   <head>
    <title><xsl:value-of select="title"/></title>
   </head>
   <body>
    <xsl:call-template name="css" />
   
    <p align="center">
     <h1><xsl:value-of select="title"/></h1>
     <xsl:apply-templates select="legal" />
    </p>
    <xsl:apply-templates select="disclaimer" />
    <hr/>
    <p>
     This guide is available in several forms:<br/>
     <a href="index.htm">To view this as a series of smaller pages, click here.</a><br/>
     <a href="printer.htm">To view a printer friendly-version, click here.</a><br/>
     <a href="javacert.zip">To download all the files related to this document as a ZIP archive, click here.</a><br/>
    </p>
    <p>
     <h2>Sections</h2>
     <a href="#full"><i>Contents</i></a><br/>
     <blockquote><xsl:for-each select="section"> 
      <a href="#{generate-id(section_title)}"><xsl:value-of select="section_title"/></a>
      <br/>
      </xsl:for-each></blockquote>
    </p>
    <xsl:apply-templates select="section" />
    <hr />
    <xsl:apply-templates select="."  mode="contents" />
   </body>
  </html>
 </xsl:template>

 <xsl:template match="*" mode="contents">
  <p>
   <a name="full"><h2>Contents</h2></a>
    <xsl:for-each select="section"> 
     <blockquote><a href="#{generate-id(section_title)}"><h3><xsl:value-of select="section_title"/></h3></a>
      <xsl:for-each select=".//objh"> 
       <blockquote><a href="#{generate-id()}"><xsl:value-of select="."/></a>
       <br/>
       <xsl:for-each select="..//*[name()='subh' or name()='big']"> 
        <blockquote><a href="#{generate-id()}"><small><xsl:value-of select="."/></small></a>
         <br/>
        </blockquote>
       </xsl:for-each>
       </blockquote>
      </xsl:for-each>
      <!-- The introduction section has 'subh's but no objectives -->
      <xsl:for-each select="*[name()='subh' or name()='big']"> 
       <blockquote>
        <blockquote><a href="{generate-id(../section_title)}.htm#{generate-id()}"><small><xsl:value-of select="."/></small></a>
         <br/>
        </blockquote>
       </blockquote>
      </xsl:for-each>
     </blockquote>
    </xsl:for-each>
  </p>
</xsl:template>
 
 <xsl:template match="disclaimer">
  <a name="disclaimer"><h2>Disclaimers</h2></a><xsl:apply-templates />
 </xsl:template>


 <!-- 	
 TM symbol 
 &trade; not compatible with Netscape, 
 &#8482 is replace by XT with &trade;,
 so using output escaping 
 -->
 <xsl:template match="trademark">
  <xsl:text disable-output-escaping="yes">&amp;#8482;</xsl:text>
 </xsl:template>

 <!-- Copyright symbol -->
 <xsl:template match="copyright">
  <!-- Ideally should use the right character code -->
  <xsl:text disable-output-escaping="yes">&amp;copy;</xsl:text>
 </xsl:template>


 <!-- Heading of each section -->
 <xsl:template match="section_title">
  <a name="{generate-id()}"><hr /><h2><xsl:apply-templates /></h2></a>
 </xsl:template>

 <xsl:template match="obj">
  <xsl:apply-templates select="objh" />
  <xsl:if test="not(./*[2])"><br/></xsl:if>
  <xsl:apply-templates select="node()[not(local-name()='objh')]"/>
  <xsl:if test="not(./*[2])"><br/></xsl:if>
 </xsl:template>
 
 <!-- The objective as described by Sun -->
 <xsl:template match="objh">
  <br/>
  <table cellpadding="5" cellspacing="0" border="0" bgcolor="black" width="100%" >
   <tr>
    <td class="objh">
     <font color="white">
      <a name="{generate-id()}"/><xsl:apply-templates />
     </font>
    </td>
   </tr>
  </table>
 </xsl:template>


 <!-- sub headings -->
 <xsl:template match="subh">
 	<h3><a name="{generate-id()}"/><xsl:apply-templates /></h3>
 </xsl:template>
  
 <!-- big sub headings -->
 <xsl:template match="big">
  <h2><a name="{generate-id()}"/><xsl:apply-templates /></h2>
 </xsl:template>
 
 <!-- section to be indented e.g. a definition -->
 <xsl:template match="def">
  <blockquote><xsl:apply-templates /></blockquote>
 </xsl:template>
 
 <!-- Program code that is part of a paragraph -->
 <xsl:template match="pcode">
  <code><xsl:apply-templates /></code>
 </xsl:template>
 
 <!-- Program code which stands alone and need to
 preserve whitespace -->
 <xsl:template match="code">
  <pre><xsl:apply-templates /></pre>
 </xsl:template>
 
 <!-- High-lighted text -->
 <xsl:template match="hilite">
  <font color="red"><xsl:apply-templates /></font>
 </xsl:template>
 
 <!-- Abstraction for a table -->
 <xsl:template match="grid">
  <table border="1" bgcolor="black" cellPadding="3" cellSpacing="0">
   <xsl:apply-templates />
  </table>
  <br/>
 </xsl:template>

 
 <xsl:template match="loosegrid">
  <table cellpadding="5">
  <xsl:apply-templates select="gridtitle" />
  <xsl:for-each select="item[position() mod 5 = 1]">
   <tr>
    <xsl:apply-templates select=".|following-sibling::item[position() &lt; 5]" mode="normal" />
   </tr>
  </xsl:for-each>
  </table>
  <br/>
 </xsl:template>
  

 <xsl:template match="gridtitle">
  <caption><b><xsl:apply-templates /></b></caption>
 </xsl:template>
  

 <xsl:template match="row">
  <tr><xsl:apply-templates select="item" mode="normal" /></tr>
 </xsl:template>


 <xsl:template match="hrow">
  <thead>
   <tr>
    <xsl:apply-templates select="item" mode="heading" />
   </tr>
  </thead>
 </xsl:template>
 

 <xsl:template match="item" mode="normal">
  <td bgcolor="white"><xsl:apply-templates /></td>
 </xsl:template>
 

 <xsl:template match="item" mode="heading">
  <td bgcolor="#cccccc"><b><xsl:apply-templates /></b></td>
 </xsl:template>
 
 
 <!-- These elements map directly to HTML -->
 
 <!-- anchors -->
 <xsl:template match="a">
  <a href="{@href}"><xsl:apply-templates /></a>
 </xsl:template>
 
 <!-- images -->
 <xsl:template match="img">
  <img src="{@src}" />
 </xsl:template>
 
 <!-- breaks -->
 <xsl:template match="br">
  <br />
 </xsl:template>
 
 <!-- paragraphs -->
 <xsl:template match="p">
  <p><xsl:apply-templates /></p>
 </xsl:template>
 
 <!-- Superscript i.e. exponents -->
 <xsl:template match="sup">
  <sup><xsl:apply-templates /></sup>
 </xsl:template>
 
 <!-- bold -->
 <xsl:template match="b">
  <b><xsl:apply-templates /></b>
 </xsl:template>
 
 <!-- underline -->
 <xsl:template match="u">
  <u><xsl:apply-templates /></u>
 </xsl:template>
 
 <!-- italic -->
 <xsl:template match="i">
  <i><xsl:apply-templates /></i>
 </xsl:template>
 
 <!-- bulleted list -->
 <xsl:template match="ul">
  <ul><xsl:apply-templates /></ul>
 </xsl:template>
 
 <!-- numbered list -->
 <xsl:template match="ol">
  <ol><xsl:apply-templates /></ol>
 </xsl:template>
 
 <!-- list item -->
 <xsl:template match="li">
  <li><xsl:apply-templates /></li>
 </xsl:template>
 
 <!-- A section  -->
 <xsl:template match="section">
  <xsl:apply-templates />
 </xsl:template>
 
 <xsl:template name="css">
 	<!-- The following CSS is messy, but it renders reasonably consistantly in Netscape 4.X and IE 4/5. -->
		<STYLE TYPE="text/css">
			<xsl:comment>
				body { font-family : Arial, sans-serif; font-size : 10pt}
				p { font-family : Arial, sans-serif; font-size : 10pt}
				a { font-family : Arial, sans-serif; font-size : 10pt}
				h1 { font-family: Arial, sans-serif; font-size : 24pt}
				h2 { font-family: Arial, sans-serif; font-size : 18pt}
				h3 { font-family: Arial, sans-serif; font-size : 10pt}
				td { font-family : Arial, sans-serif; font-size : 10pt}
				ul { font-family : Arial, sans-serif; font-size : 10pt}
				ol { font-family : Arial, sans-serif; font-size : 10pt}
				li { font-family : Arial, sans-serif; font-size : 10pt}
				blockquote { font-family : Arial, sans-serif; font-size : 10pt}
				code { font-size : 10pt}
				pre { font-size : 10pt}
				td.objh { font-family : Arial, sans-serif; font-size : 12pt}
				td { font-family : Arial, sans-serif; font-size : 10pt}
			</xsl:comment>
		</STYLE>
 </xsl:template>
</xsl:stylesheet>
